# Generated by Django 4.2.21 on 2025-05-29 21:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("evewiki", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="page",
            name="is_public",
            field=models.BooleanField(
                default=False,
                help_text="Optional: Make page publicly accessible via it's [path]/[slug]",
            ),
        ),
    ]
